@@ -13,9 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import pecan
 from wsme import types as wtypes
 
+from ironic import api
 from ironic.api.controllers import base
 from ironic.api.controllers import link
 
@@ -43,10 +43,15 @@ class Collection(base.APIBase):
             return wtypes.Unset
 
         resource_url = url or self._type
+        fields = kwargs.pop('fields', None)
+        # NOTE(saga): If fields argument is present in kwargs and not None. It
+        # is a list so convert it into a comma seperated string.
+        if fields:
+            kwargs['fields'] = ','.join(fields)
         q_args = ''.join(['%s=%s&' % (key, kwargs[key]) for key in kwargs])
         next_args = '?%(args)slimit=%(limit)d&marker=%(marker)s' % {
             'args': q_args, 'limit': limit,
             'marker': getattr(self.collection[-1], self.get_key_field())}
 
-        return link.Link.make_link('next', pecan.request.public_url,
+        return link.Link.make_link('next', api.request.public_url,
                                    resource_url, next_args).href
