@@ -37,9 +37,7 @@ _opts = [
     ('ansible', ironic.conf.ansible.opts),
     ('api', ironic.conf.api.opts),
     ('audit', ironic.conf.audit.opts),
-    ('cimc', ironic.conf.cisco.cimc_opts),
     ('cinder', ironic.conf.cinder.list_opts()),
-    ('cisco_ucs', ironic.conf.cisco.ucsm_opts),
     ('conductor', ironic.conf.conductor.opts),
     ('console', ironic.conf.console.opts),
     ('database', ironic.conf.database.opts),
@@ -57,6 +55,7 @@ _opts = [
     ('metrics', ironic.conf.metrics.opts),
     ('metrics_statsd', ironic.conf.metrics_statsd.opts),
     ('neutron', ironic.conf.neutron.list_opts()),
+    ('nova', ironic.conf.nova.list_opts()),
     ('pxe', ironic.conf.pxe.opts),
     ('service_catalog', ironic.conf.service_catalog.list_opts()),
     ('snmp', ironic.conf.snmp.opts),
@@ -89,7 +88,9 @@ def update_opt_defaults():
             'amqp=WARNING',
             'amqplib=WARNING',
             'qpid.messaging=INFO',
+            # This comes in two flavors
             'oslo.messaging=INFO',
+            'oslo_messaging=INFO',
             'sqlalchemy=WARNING',
             'stevedore=INFO',
             'eventlet.wsgi.server=INFO',
