@@ -41,16 +41,41 @@ ilo_error = importutils.try_import('proliantutils.exception')
 class Ilo5RAID(base.RAIDInterface):
     """Implementation of OOB RAIDInterface for iLO5."""
 
+    _RAID_APPLY_CONFIGURATION_ARGSINFO = {
+        "raid_config": {
+            "description": "The RAID configuration to apply.",
+            "required": True,
+        },
+        "create_root_volume": {
+            "description": (
+                "Setting this to 'False' indicates not to create root "
+                "volume that is specified in 'raid_config'. Default "
+                "value is 'True'."
+            ),
+            "required": False,
+        },
+        "create_nonroot_volumes": {
+            "description": (
+                "Setting this to 'False' indicates not to create "
+                "non-root volumes (all except the root volume) in "
+                "'raid_config'. Default value is 'True'."
+            ),
+            "required": False,
+        }
+    }
+
     def get_properties(self):
         """Return the properties of the interface."""
         return ilo_common.REQUIRED_PROPERTIES
 
-    def _set_clean_failed(self, task, msg, exc):
+    def _set_step_failed(self, task, msg, exc):
         LOG.error("RAID configuration job failed for node %(node)s. "
                   "Message: '%(message)s'.",
                   {'node': task.node.uuid, 'message': msg})
-        task.node.last_error = msg
-        task.process_event('fail')
+        if task.node.provision_state == states.DEPLOYING:
+            manager_utils.deploying_error_handler(task, msg, msg)
+        else:
+            manager_utils.cleaning_error_handler(task, msg)
 
     def _set_driver_internal_true_value(self, task, *keys):
         driver_internal_info = task.node.driver_internal_info
@@ -83,8 +108,16 @@ class Ilo5RAID(base.RAIDInterface):
         else:
             self._set_driver_internal_true_value(
                 task, 'ilo_raid_delete_in_progress')
-        self._set_driver_internal_true_value(task, 'cleaning_reboot')
-        self._set_driver_internal_false_value(task, 'skip_current_clean_step')
+        deploy_utils.set_async_step_flags(task.node, reboot=True,
+                                          skip_current_step=False)
+
+    @base.deploy_step(priority=0,
+                      argsinfo=_RAID_APPLY_CONFIGURATION_ARGSINFO)
+    def apply_configuration(self, task, raid_config, create_root_volume=True,
+                            create_nonroot_volumes=False):
+        return super(Ilo5RAID, self).apply_configuration(
+            task, raid_config, create_root_volume=create_root_volume,
+            create_nonroot_volumes=create_nonroot_volumes)
 
     @METRICS.timer('Ilo5RAID.create_configuration')
     @base.clean_step(priority=0, abortable=False, argsinfo={
@@ -119,7 +152,8 @@ class Ilo5RAID(base.RAIDInterface):
         :raises: MissingParameterValue, if node.target_raid_config is missing
             or was found to be empty after skipping root volume and/or non-root
             volumes.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute clean step.
+        :raises: InstanceDeployFailure, on failure to execute deploy step.
         """
         node = task.node
         target_raid_config = raid.filter_target_raid_config(
@@ -139,44 +173,52 @@ class Ilo5RAID(base.RAIDInterface):
             if not driver_internal_info.get('ilo_raid_create_in_progress'):
                 ilo_object.create_raid_configuration(target_raid_config)
                 self._prepare_for_read_raid(task, 'create_raid')
-                return states.CLEANWAIT
+                return deploy_utils.get_async_step_return_state(node)
             else:
                 # Raid configuration is done, updating raid_config
                 raid_conf = (
                     ilo_object.read_raid_configuration(
                         raid_config=target_raid_config))
+                fields = ['ilo_raid_create_in_progress']
+                if node.clean_step:
+                    fields.append('skip_current_clean_step')
+                else:
+                    fields.append('skip_current_deploy_step')
+                self._pop_driver_internal_values(task, *fields)
                 if len(raid_conf['logical_disks']):
                     raid.update_raid_info(node, raid_conf)
                     LOG.debug("Node %(uuid)s raid create clean step is done.",
                               {'uuid': node.uuid})
-                    self._pop_driver_internal_values(
-                        task, 'ilo_raid_create_in_progress',
-                        'skip_current_clean_step')
                 else:
                     # Raid configuration failed
-                    msg = "Unable to create raid"
-                    self._pop_driver_internal_values(
-                        task, 'ilo_raid_create_in_progress',
-                        'skip_current_clean_step')
-                    raise exception.NodeCleaningFailure(
-                        "Clean step create_configuration failed "
-                        "on node %(node)s with error: %(err)s" %
-                        {'node': node.uuid, 'err': msg})
+                    msg = (_("Step create_configuration failed "
+                             "on node %(node)s with error: "
+                             "Unable to create raid")
+                           % {'node': node.uuid})
+                    if node.clean_step:
+                        raise exception.NodeCleaningFailure(msg)
+                    else:
+                        raise exception.InstanceDeployFailure(reason=msg)
         except ilo_error.IloError as ilo_exception:
             operation = (_("Failed to create raid configuration on node %s")
                          % node.uuid)
-            self._pop_driver_internal_values(task,
-                                             'ilo_raid_create_in_progress',
-                                             'skip_current_clean_step')
-            self._set_clean_failed(task, operation, ilo_exception)
+            fields = ['ilo_raid_create_in_progress']
+            if node.clean_step:
+                fields.append('skip_current_clean_step')
+            else:
+                fields.append('skip_current_deploy_step')
+            self._pop_driver_internal_values(task, *fields)
+            self._set_step_failed(task, operation, ilo_exception)
 
     @METRICS.timer('Ilo5RAID.delete_configuration')
     @base.clean_step(priority=0, abortable=False)
+    @base.deploy_step(priority=0)
     def delete_configuration(self, task):
         """Delete the RAID configuration.
 
         :param task: a TaskManager instance  containing the node to act on.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute clean step.
+        :raises: InstanceDeployFailure, on failure to execute deploy step.
         """
         node = task.node
         LOG.debug("OOB RAID delete_configuration invoked for node %s.",
@@ -189,28 +231,32 @@ class Ilo5RAID(base.RAIDInterface):
             if not driver_internal_info.get('ilo_raid_delete_in_progress'):
                 ilo_object.delete_raid_configuration()
                 self._prepare_for_read_raid(task, 'delete_raid')
-                return states.CLEANWAIT
+                return deploy_utils.get_async_step_return_state(node)
             else:
                 # Raid configuration is done, updating raid_config
                 raid_conf = ilo_object.read_raid_configuration()
+                fields = ['ilo_raid_delete_in_progress']
+                if node.clean_step:
+                    fields.append('skip_current_clean_step')
+                else:
+                    fields.append('skip_current_deploy_step')
+                self._pop_driver_internal_values(task, *fields)
                 if not len(raid_conf['logical_disks']):
                     node.raid_config = {}
                     LOG.debug("Node %(uuid)s raid delete clean step is done.",
                               {'uuid': node.uuid})
-                    self._pop_driver_internal_values(
-                        task, 'ilo_raid_delete_in_progress',
-                        'skip_current_clean_step')
                 else:
                     # Raid configuration failed
-                    msg = ("Unable to delete this logical disks: %s" %
-                           raid_conf['logical_disks'])
-                    self._pop_driver_internal_values(
-                        task, 'ilo_raid_delete_in_progress',
-                        'skip_current_clean_step')
-                    raise exception.NodeCleaningFailure(
-                        "Clean step delete_configuration failed "
-                        "on node %(node)s with error: %(err)s" %
-                        {'node': node.uuid, 'err': msg})
+                    err_msg = (_("Step delete_configuration failed "
+                                 "on node %(node)s with error: "
+                                 "Unable to delete these logical disks: "
+                                 "%(disks)s")
+                               % {'node': node.uuid,
+                                  'disks': raid_conf['logical_disks']})
+                    if node.clean_step:
+                        raise exception.NodeCleaningFailure(err_msg)
+                    else:
+                        raise exception.InstanceDeployFailure(reason=err_msg)
         except ilo_error.IloLogicalDriveNotFoundError:
             LOG.info("No logical drive found to delete on node %(node)s",
                      {'node': node.uuid})
@@ -220,4 +266,10 @@ class Ilo5RAID(base.RAIDInterface):
             self._pop_driver_internal_values(task,
                                              'ilo_raid_delete_in_progress',
                                              'skip_current_clean_step')
-            self._set_clean_failed(task, operation, ilo_exception)
+            fields = ['ilo_raid_delete_in_progress']
+            if node.clean_step:
+                fields.append('skip_current_clean_step')
+            else:
+                fields.append('skip_current_deploy_step')
+            self._pop_driver_internal_values(task, *fields)
+            self._set_step_failed(task, operation, ilo_exception)
