@@ -25,6 +25,7 @@ from ironic.common.i18n import _
 from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.drivers import base
+from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules.redfish import utils as redfish_utils
 
 LOG = log.getLogger(__name__)
@@ -215,6 +216,10 @@ class RedfishManagement(base.ManagementInterface):
             LOG.error(error_msg)
             raise exception.RedfishError(error=error_msg)
 
+        # Ensure that boot mode is synced with what is set.
+        # Some BMCs reset it to default (BIOS) when changing the boot device.
+        boot_mode_utils.sync_boot_mode(task)
+
     def get_boot_device(self, task):
         """Get the current boot device for a node.
 
