@@ -21,10 +21,14 @@ import six
 from six.moves import http_client
 
 from ironic.common import exception
+from ironic import conf
 from ironic.drivers.modules import agent_client
 from ironic.tests import base
 
 
+CONF = conf.CONF
+
+
 class MockResponse(object):
     def __init__(self, text, status_code=http_client.OK):
         assert isinstance(text, six.string_types)
@@ -181,6 +185,23 @@ class TestAgentClient(base.TestCase):
             res.json.return_value = {'commands': []}
             mock_get.return_value = res
             self.assertEqual([], self.client.get_commands_status(self.node))
+            agent_url = self.node.driver_internal_info.get('agent_url')
+            mock_get.assert_called_once_with(
+                '%(agent_url)s/%(api_version)s/commands' % {
+                    'agent_url': agent_url,
+                    'api_version': CONF.agent.agent_api_version},
+                timeout=CONF.agent.command_timeout)
+
+    def test_get_commands_status_retries(self):
+        with mock.patch.object(self.client.session, 'get',
+                               autospec=True) as mock_get:
+            res = mock.MagicMock(spec_set=['json'])
+            res.json.return_value = {'commands': []}
+            mock_get.side_effect = [
+                requests.ConnectionError('boom'),
+                res]
+            self.assertEqual([], self.client.get_commands_status(self.node))
+            self.assertEqual(2, mock_get.call_count)
 
     def test_prepare_image(self):
         self.client._command = mock.MagicMock(spec_set=[])
@@ -262,7 +283,8 @@ class TestAgentClient(base.TestCase):
             self.node, root_uuid, efi_system_part_uuid=efi_system_part_uuid,
             prep_boot_part_uuid=prep_boot_part_uuid)
         self.client._command.assert_called_once_with(
-            node=self.node, method='image.install_bootloader', params=params,
+            command_timeout_factor=2, node=self.node,
+            method='image.install_bootloader', params=params,
             wait=True)
 
     def test_install_bootloader(self):
